/****************************************************************************
 *
 *   Copyright (C) 2003, 2004 Wolfgang G. Reissnegger, All Rights Reserved
 *
 *   gnagflow@users.sourceforge.net                                    
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License as
 *   published by the Free Software Foundation; either version 2 of
 *   the license, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public
 *   License along with this program;  if not, write to the
 *       Free Software Foundation, Inc.,
 *       59 Temple Place - Suite 330,
 *       Boston, MA 02111-1307
 *
 ****************************************************************************/

#ifndef config_data_H_
#define config_data_H_

// Read the config data from a file.
//
// This method will open the file, read the data and close the file again.
// After calling this function, the content of the config file will be kept in
// a memory cache.
//
// NOTE:
//   Reading a file while there is data in the data cache will cause the data
//   cache to be cleared and overwritten.
//
int config_data_read(const char *filename);

// Write the config data to a file.
//
// This function will open the file, write the data and close the file again.
// The content of the memory cache will be written to the config file.
//
// NOTE:
//   config_data_write will OVERWRITE an existing file. If you want to append
//   values to the file you have to read it first, change it and then write it
//   back.
//
int config_data_write(const char *filename);

// Clears the data cache in memory. This will free up the memory used for the
// cache. All changes will be lost if config_data_write() is not called before
// config_data_clear().
//
void config_data_clear(void);

// Get a value for a given key. A key can be any given string not containing a
// '=' character.
//
const char *config_data_get(const char *key);

// Set the value for a given key. A value can be any given string not
// containing a '=' character.
//
void config_data_set(const char *key, const char *value);

#endif
