/****************************************************************************
 *
 *   Copyright (C) 2003, 2004 Wolfgang G. Reissnegger, All Rights Reserved
 *
 *   gnagflow@users.sourceforge.net                                    
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License as
 *   published by the Free Software Foundation; either version 2 of
 *   the license, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public
 *   License along with this program;  if not, write to the
 *       Free Software Foundation, Inc.,
 *       59 Temple Place - Suite 330,
 *       Boston, MA 02111-1307
 *
 ****************************************************************************/

#include <stdio.h>
#include <assert.h>
#include <string.h>

#include "fileutil.h"
#include "defs.h"
#include "playlist.h"

/******************************************************************************
 *
 * playlist_read_file
 *
 * Reads a given file from disk and returns a list_t *of the file content.
 *
 * Fails if NULL filename given.
 *
 * Returns NULL on ERROR and if file does not exist.
 *
 ******************************************************************************/

list_t *playlist_read_file(const char *fullpath)
{
	FILE *fp;
	char line[MAX_PATH_LEN];
	char *p;
	list_t *filelist = NULL;

	assert(NULL != fullpath);

	fp = fopen(fullpath, "r");

	if (fp)
	{
		do
		{
			p = fgets(line, sizeof(line), fp);

			if (p)
			{
				// remove the \n at the end, if it exists
				//
				if ('\n' == p[strlen(p) - 1])
					p[strlen(p) - 1] = '\0';

				// add the entry to the list
				//
				filelist = list_add(filelist, file_entry_new(line));
			}
		}
		while (p);


		fclose(fp);
	}
	return filelist;
}


/******************************************************************************
 *
 * playlist_write_file
 *
 * Writes the content of the given list into the given file.
 *
 * Fails on NULL filename.
 *
 * Returns 0 on success and -1 on ERROR.
 *
 ******************************************************************************/

int playlist_write_file(list_t *list, const char *fullpath)
{
	FILE *fp;
	list_t *iter;

	assert(NULL != fullpath);

	fp = fopen(fullpath, "w");
	if (!fp)
		return -1;


	for (iter = list_first(list); iter; iter = list_next(iter))
	{
		file_entry_t *entry = list_data(iter);

		fprintf(fp, "%s\n", entry->fullpath);
	}

	fclose(fp);
	return 0;
}
