/****************************************************************************
 *
 *   Copyright (C) 2003, 2004 Wolfgang G. Reissnegger, All Rights Reserved
 *
 *   gnagflow@users.sourceforge.net                                    
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License as
 *   published by the Free Software Foundation; either version 2 of
 *   the license, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public
 *   License along with this program;  if not, write to the
 *       Free Software Foundation, Inc.,
 *       59 Temple Place - Suite 330,
 *       Boston, MA 02111-1307
 *
 ****************************************************************************/

#include "tools.h"

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <fcntl.h>
#include <sys/stat.h>
#include <sys/types.h>
#include "display.h"
#include "menu.h"
#include "info.h"
#include "util.h"

/******************************************************************************/

static void tools_rescan_songlist(void *data)
{
	display_push(info_new("Scanning Songlist", 0));
	display_show();

	// Remove the playlist cache file
	//
	system("rm -rf " AUDIOBOX_PLAYLIST_CACHE_FILE);

	// Re-scan the file list from the file system. This will also write a
	// new playlist cache file.
	//
	// NOTE: FIXME
	//   Clearing the file_list here will spell disaster if there are any
	//   other sessions open with references to the previously existing
	//   list...  Probably we should do something about it...
	//
	file_entry_list_init();

	display_pop();

	display_push(info_new("Scan complete.", 5000));
}


/******************************************************************************/
/*
static void tools_update_audioBox(void *data)
{
	display_push(info_new("Updating audioBox...", 0));
	display_show();

//	system("mount " DIR_FLOPPY_DEV);
//	system("cp -f " DIR_FLOPPY_DEV "/audioBox /usr/local/bin");
//	system("umount " DIR_FLOPPY_DEV);
	system("chown root:root /mp3/audiobox");
	system("chmod 755 /mp3/audiobox");
	system("mv -f /mp3/audiobox /usr/bin/audiobox");
	sleep(1);
	display_pop();
	display_push(info_new("Update complete.", 5000));
}
*/
/******************************************************************************/

static void tools_toggle_startsound(void *data)
{
	int fh;
	if((fh=open(AUDIOBOX_STARTSOUND,O_RDONLY)) == -1) 
	{
		display_push(info_new("Switching ON StartSound", 1500));
		symlink(AUDIOBOX_REAL_STARTSOUND, AUDIOBOX_STARTSOUND);
	}
	else
	{
		close(fh);
		display_push(info_new("Switching OFF StartSound", 1500));
		remove(AUDIOBOX_STARTSOUND);
	}
}

/******************************************************************************/

static void tools_copy_cd_to_hdd(void *data)
{
	char cmd[MAX_PATH_LEN * 2];
	screen_t *info;

	display_push(info_new("Copying CD...", 0));
	display_show();

	system("mount " DIR_CDROM_DEV);
	sprintf(cmd, "cp -rf " DIR_CDROM_DEV "/* %s", DIR_MP3);
	system(cmd);
	system("umount " DIR_CDROM_DEV);
	display_pop();

	// Re-scan the file list
	//
	info = info_new("Copy complete.", 0);
	info_set_text(info, 1, "Re-scanning files...");
	display_push(info);
	display_show();

	file_entry_list_deinit();
	file_entry_list_init();

	// Done.
	//
	display_pop();
}


/******************************************************************************/

static void tools_about(void *data)
{
	screen_t *info;

	info = info_new("audioBox " VERSION "a by Wolfgang Reissnegger," , ABOUT_SCREEN_TIMEOUT);
	info_set_text(info, 1, "with some improvements by PPG & T.E.");
	display_push(info);
	display_show();
}


/******************************************************************************/

void tools_menu(void *data)
{
	screen_t *tools_menu = menu_new();

	menu_add(tools_menu, "Re-Scan Songlist", tools_rescan_songlist);
	menu_add(tools_menu, "Copy CD->HDD", tools_copy_cd_to_hdd);
//	menu_add(tools_menu, "Update (be sure you have one!)", tools_update_audioBox);
	menu_add(tools_menu, "Toggle StartSound", tools_toggle_startsound);
	menu_add(tools_menu, "About audioBox", tools_about);

	display_push(tools_menu);
}
