/****************************************************************************
 *
 *   Copyright (C) 2003, 2004 Wolfgang G. Reissnegger, All Rights Reserved
 *
 *   gnagflow@users.sourceforge.net                                    
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License as
 *   published by the Free Software Foundation; either version 2 of
 *   the license, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public
 *   License along with this program;  if not, write to the
 *       Free Software Foundation, Inc.,
 *       59 Temple Place - Suite 330,
 *       Boston, MA 02111-1307
 *
 ****************************************************************************/

// This is a template to help you implement your own display drivers for
// audioBox. It contains templates for all the functions that must or can be
// implemented. Simply replace 'myplugin' with the name of your display and add
// your code where needed. It is always a good idea to look at other plugins
// for ideas...
//

// Compile only, if this driver is enabled
//
#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

// Conditional compile of your code.
//
#ifdef AUDIOBOX_ENABLE_MYPLUGIN

#include "display_plugin_template.h"

// These includes provide the context object definitions. You NEED to include those!
//
#include "song.h"
#include "info.h"
#include "search.h"
#include "menu.h"

/******************************************************************************/

// Prototypes for 'class' functions
//
static int  myplugin_open(display_t *display);
static void myplugin_close(display_t *display);
static int  myplugin_fd(display_t *display);
static void myplugin_handle_event(display_t *display);
static void myplugin_show(display_t *display, void *ctx, unsigned int type);
static void myplugin_cmd(display_t *display, unsigned int cmd, void *arg);


/******************************************************************************
 *
 * Definition of the display device structure
 *
 ******************************************************************************/

// This structure defines the generic myplugin attributes.
//
struct myplugin_d
{
	// You have to 'inherit' the parent 'class'!
	//
	// parent MUST be the first member in myplugin_d!
	//
	display_t	parent;

	// Add you own per-display vriables here. The following variables are
	// only examples and are not required.
	//
	int	myplugin_sock;		// socket fd
	int	myplugin_var1;
	char	myplugin_buf[32];

// The following macros make it easy to access your data members in myplugin_d
// when a display_t* is passed to your methods.
//
#define m_myplugin_sock		((struct myplugin_d *) display)->myplugin_sock
#define m_myplugin_var1		((struct myplugin_d *) display)->myplugin_var1
#define m_myplugin_buf		((struct myplugin_d *) display)->myplugin_buf
};


// Declaration and initialization of driver structure.
//
// NOTE: You can add as many display device structure as you want. They are all
// traeted independently in display.c. Simply define multiple structures and
// add them to display_list[] in display.c.
//
struct myplugin_d	myplugin = 
{
	// intialization of parent 'class'. You need to sepcify all the methods
	// you support in your display. You do not have to support ALL the
	// methods, though.
	//
	{
		open:		myplugin_open,
		close:		myplugin_close,
		fd:		myplugin_fd,
		ev_handler:	myplugin_handle_event,
		show:		myplugin_show,
		cmd:		myplugin_cmd,
	},

	-1,		// sock
	// Add your initializiation here (if needed)
	//
};


/******************************************************************************
 *
 * 'Class' methods
 *
 ******************************************************************************/

static int  myplugin_open(display_t *display)
{
	// This function opens your display device and initializes the driver
	// attributes as needed.
	//
	// Return o for success, -1 for error
	//
	return 0;
}


/******************************************************************************/

static void myplugin_close(display_t *display)
{
	// This function closes the display device. It must de-allocate all
	// resources that have been allocated throughout its lifetime.
	//
}


/******************************************************************************/

static int  myplugin_fd(display_t *display)
{
	// If needed, this function returns the socket fd of the device. If not
	// applicable, you can either NOT define the function and initialize
	// the myplugin_d:parent:fd structure with NULL, or simply return -1.
	//
	return m_sock;
}


/******************************************************************************/

static void myplugin_handle_event(display_t *display)
{
	// This function handles pending data. You should read your fd here.
	//
	// This might also be the place where you receive and handle KEY
	// eventes from your device. You will have to translate them into
	// KEY_xxx values (see keytab.c) and send them to hanlde_key().
	//
}


/******************************************************************************/

static void myplugin_cmd(display_t *display, unsigned int cmd, void *arg)
{
	// This is tha command handler function. Depending on your display you
	// might implement only a few commands and choose to ignore others.
	//
	assert(NULL != display);

	switch (cmd)
	{
		case CMD_CLEAR:
			// Add your code here
			//
			break;

		default:
			// ignore
			;
	}
}


/******************************************************************************
 *
 * SHOW functions for the LCD driver
 *
 * The following section defines all the SHOW functions for the different
 * screen types. Here you define how the individual display devices render the
 * information provided in the screen type context objects.
 *
 ******************************************************************************/

static void myplugin_show_menu(display_t *display, void *ctx)
{
	// This function displays a given MENU on the display. ctx contains the
	// menu context and is of type menu_display_context*.
	//
	// See menu.h for the structure definition.
	//
	// You can use the m_xxx accessor macros here.
	//

	// Add your code here...
	//
}


/******************************************************************************/

static void myplugin_show_search(display_t *display, void *ctx)
{
	// This function displays a given SEARCH screen on the display. ctx
	// contains the menu context and is of type search_display_context*.
	//
	// See search.h for the structure definition.
	//
	// You can use the m_xxx accessor macros here.
	//

	// Add your code here...
	//
}


/******************************************************************************/

static void myplugin_show_info(display_t *display, void *ctx)
{
	// This function displays a given INFO screen on the display. ctx
	// contains the menu context and is of type info_display_context*.
	//
	// See info.h for the structure definition.
	//
	// You can use the m_xxx accessor macros here.
	//

	// Add your code here...
	//
}


/******************************************************************************/

static void myplugin_show_song(display_t *display, void *ctx)
{
	// This function displays a given SONG screen on the display. ctx
	// contains the menu context and is of type song_display_context*.
	//
	// See song.h for the structure definition.
	//
	// You can use the m_xxx accessor macros here.
	//
	// This is probably the most complex show function. You will have to
	// decide which information to show on the display in which given mode.
	// You should have a look at other plugins for ideas...
	//

	// Add your code here...
	//
}


/******************************************************************************
 *
 * SHOW multiplexer function
 *
 * This is the main entry point for SHOW events. This is also the only function
 * which is registered in the myplugin_d structure. All other show functions
 * should be declared static and called by this function only.
 *
 ******************************************************************************/

static void myplugin_show(display_t *display, void *ctx, unsigned int type)
{
	// This is the main multiplexer function for show requests. You most
	// likely do not have to alter this function at all. If, in the future,
	// new screen types are added, you might have to add them here, along
	// with the correpsonding _show() function above.
	//
	assert(NULL != ctx);
	assert(NULL != display);

	switch (type)
	{
		case TYPE_MENU:		myplugin_show_menu(display, ctx);	break;
		case TYPE_SEARCH:	myplugin_show_search(display, ctx);	break;
		case TYPE_INFO:		myplugin_show_info(display, ctx);	break;
		case TYPE_SONG:		myplugin_show_song(display, ctx);	break;

		default:
			// ignore
			;
	}
}


#endif	// #ifdef AUDIOBOX_ENABLE_MYPLUGIN
